@@ -50,6 +50,7 @@
 #include "stuff.h"
 #include "env.h"
 #include "syscalls.h"
+#include "tagstring.h"
 #include "terrain.h"
 #ifdef USE_TILE
 #include "tilepick.h"
@@ -68,10 +69,14 @@ static const char *features[] = {
     "Lua user scripts",
 #endif
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     "Tile support",
 #endif
 
+#ifdef USE_TILE_WEB
+    "Web Tile support",
+#endif
+
 #ifdef WIZARD
     "Wizard mode",
 #endif
@@ -226,24 +231,6 @@ static void _print_version(void)
     // Read in information about changes in comparison to the latest version.
     FILE* fp = fopen_u(datafile_path(fname, false).c_str(), "r");
 
-#if defined(TARGET_OS_DOS)
-    if (!fp)
-    {
- #ifdef DEBUG_FILES
-        mprf(MSGCH_DIAGNOSTICS, "File '%s' could not be opened.",
-             fname.c_str());
- #endif
-        if (get_dos_compatible_file_name(&fname))
-        {
- #ifdef DEBUG_FILES
-            mprf(MSGCH_DIAGNOSTICS,
-                 "Attempting to open file '%s'", fname.c_str());
- #endif
-            fp = fopen_u(datafile_path(fname, false).c_str(), "r");
-        }
-    }
-#endif
-
     if (fp)
     {
         char buf[200];
@@ -335,6 +322,16 @@ void swap_inv_slots(int from_slot, int to_slot, bool verbose)
     }
     else // just to make sure
         you.redraw_quiver = true;
+
+    // Update the current studied manual index.
+    if (you.manual_index == to_slot)
+        you.manual_index = from_slot;
+    else if (you.manual_index == from_slot)
+        you.manual_index = to_slot;
+
+    // Remove the moved items from last_drop if they're there.
+    you.last_pickup.erase(to_slot);
+    you.last_pickup.erase(from_slot);
 }
 
 static void _adjust_item(void)
@@ -365,6 +362,8 @@ static void _adjust_item(void)
     }
 
     swap_inv_slots(from_slot, to_slot, true);
+    you.wield_change = true;
+    you.redraw_quiver = true;
 }
 
 static void _adjust_spell(void)
@@ -589,41 +588,62 @@ void list_armour()
 
 void list_jewellery(void)
 {
-    std::ostringstream jstr;
+    std::string jstr;
+    int cols = get_number_of_cols();
+    bool split = you.species == SP_OCTOPODE && cols > 84;
 
-    for (int i = EQ_LEFT_RING; i <= EQ_AMULET; i++)
+    for (int i = EQ_LEFT_RING; i < NUM_EQUIP; i++)
     {
+        if ((you.species != SP_OCTOPODE && i > EQ_AMULET)
+            || (you.species == SP_OCTOPODE && i < EQ_AMULET))
+            continue;
+
         const int jewellery_id = you.equip[i];
         int       colour       = MSGCOL_BLACK;
 
-        jstr.str("");
-        jstr.clear();
-
-        jstr << ((i == EQ_LEFT_RING)  ? "Left ring " :
+        const char *slot =
+                 (i == EQ_LEFT_RING)  ? "Left ring" :
                  (i == EQ_RIGHT_RING) ? "Right ring" :
-                 (i == EQ_AMULET)     ? "Amulet    "
-                                      : "unknown   ")
-             << " : ";
+                 (i == EQ_AMULET)     ? "Amulet" :
+                 (i == EQ_RING_ONE)   ? "1st ring" :
+                 (i == EQ_RING_TWO)   ? "2nd ring" :
+                 (i == EQ_RING_THREE) ? "3rd ring" :
+                 (i == EQ_RING_FOUR)  ? "4th ring" :
+                 (i == EQ_RING_FIVE)  ? "5th ring" :
+                 (i == EQ_RING_SIX)   ? "6th ring" :
+                 (i == EQ_RING_SEVEN) ? "7th ring" :
+                 (i == EQ_RING_EIGHT) ? "8th ring"
+                                      : "unknown";
 
+        std::string item;
         if (jewellery_id != -1 && !you_tran_can_wear(you.inv[jewellery_id])
             || !you_tran_can_wear(i))
         {
-            jstr << "    (currently unavailable)";
+            item = "    (currently unavailable)";
         }
         else if (jewellery_id != -1)
         {
-            jstr << you.inv[jewellery_id].name(DESC_INVENTORY);
+            item = you.inv[jewellery_id].name(DESC_INVENTORY);
             std::string
                 prefix = menu_colour_item_prefix(you.inv[jewellery_id]);
-            colour = menu_colour(jstr.str(), prefix, "equip");
+            colour = menu_colour(item, prefix, "equip");
         }
         else
-            jstr << "    none";
+            item = "    none";
 
         if (colour == MSGCOL_BLACK)
-            colour = menu_colour(jstr.str(), "", "equip");
+            colour = menu_colour(item, "", "equip");
 
-        mpr(jstr.str().c_str(), MSGCH_EQUIPMENT, colour);
+        item = chop_string(make_stringf("%-*s: %s",
+                                        split ? cols > 96 ? 9 : 8 : 11,
+                                        slot, item.c_str()),
+                           split && i > EQ_AMULET ? (cols - 1) / 2 : cols);
+        item = colour_string(item, colour);
+
+        if (split && i > EQ_AMULET && (i - EQ_AMULET) % 2)
+            jstr = item + " ";
+        else
+            mpr(jstr + item, MSGCH_EQUIPMENT);
     }
 }
 
@@ -858,7 +878,7 @@ help_file help_files[] = {
     { "quickstart.txt",    '^', false },
     { "macros_guide.txt",  '~', false },
     { "options_guide.txt", '&', false },
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     { "tiles_help.txt",    'T', false },
 #endif
     { NULL, 0, false }
@@ -887,8 +907,8 @@ static bool _compare_mon_toughness(MenuEntry *entry_a, MenuEntry* entry_b)
     if (a->type == b->type)
         return (false);
 
-    int a_toughness = mons_difficulty(a->type);
-    int b_toughness = mons_difficulty(b->type);
+    int a_toughness = mons_avg_hp(a->type);
+    int b_toughness = mons_avg_hp(b->type);
 
     if (a_toughness == b_toughness)
     {
@@ -976,9 +996,9 @@ static std::vector<std::string> _get_desc_keys(std::string regex,
     std::vector<std::string> body_matches = getLongDescBodiesByRegex(regex,
                                                                      filter);
 
-    if (key_matches.size() == 0 && body_matches.size() == 0)
+    if (key_matches.empty() && body_matches.empty())
         return (key_matches);
-    else if (key_matches.size() == 0 && body_matches.size() == 1)
+    else if (key_matches.empty() && body_matches.size() == 1)
         return (body_matches);
 
     // Merge key_matches and body_matches, discarding duplicates.
@@ -1043,11 +1063,8 @@ static std::vector<std::string> _get_branch_keys()
         Branch     &branch       = branches[which_branch];
 
         // Skip unimplemented branches
-        if (branch.depth < 1 || i == BRANCH_FOREST || i == BRANCH_SPIDER_NEST
-            || i == BRANCH_DWARVEN_HALL)
-        {
+        if (branch.depth < 1 || branch.shortname == NULL)
             continue;
-        }
 
         names.push_back(branch.shortname);
     }
@@ -1242,10 +1259,7 @@ static bool _append_books(std::string &desc, item_def &item, std::string key)
     if (!already)
         desc += "None";
 
-    desc += "\nLevel:      ";
-    char sval[3];
-    itoa(spell_difficulty(type), sval, 10);
-    desc += sval;
+    desc += make_stringf("\nLevel:      %d", spell_difficulty(type));
 
     bool undead = false;
     if (you_cannot_memorise(type, undead))
@@ -1422,7 +1436,7 @@ static bool _do_description(std::string key, std::string type,
     inf.body << desc;
 
     key = uppercase_first(key);
-    linebreak_string2(footer, width - 1);
+    linebreak_string(footer, width - 1);
 
     inf.footer = footer;
     inf.title  = key;
@@ -1456,7 +1470,7 @@ static bool _handle_FAQ()
 
         std::string question = getFAQ_Question(question_keys[i]);
         // Wraparound if the question is longer than fits into a line.
-        linebreak_string2(question, width - 4);
+        linebreak_string(question, width - 4);
         std::vector<formatted_string> fss;
         formatted_string::parse_string_to_multiple(question, fss);
 
@@ -1496,9 +1510,9 @@ static bool _handle_FAQ()
                          "bug report!";
             }
             answer = "Q: " + getFAQ_Question(key) + "\n" + answer;
-            linebreak_string2(answer, width - 1);
+            linebreak_string(answer, width - 1);
             print_description(answer);
-            wait_for_keypress();
+            getchm();
         }
     }
 
@@ -1539,7 +1553,7 @@ static void _find_description(bool *again, std::string *error_inout)
     {
     case 'M':
         type       = "monster";
-        extra      = "  Enter a single letter to list monsters displayed by "
+        extra      = " Enter a single letter to list monsters displayed by "
                      "that symbol.";
         filter     = _monster_filter;
         recap      = _recap_mon_keys;
@@ -1564,7 +1578,7 @@ static void _find_description(bool *again, std::string *error_inout)
         break;
     case 'I':
         type        = "item";
-        extra       = "  Enter a single letter to list items displayed by "
+        extra       = " Enter a single letter to list items displayed by "
                       "that symbol.";
         filter      = _item_filter;
         doing_items = true;
@@ -1657,7 +1671,7 @@ static void _find_description(bool *again, std::string *error_inout)
     if (recap != NULL)
         (*recap)(key_list);
 
-    if (key_list.size() == 0)
+    if (key_list.empty())
     {
         if (by_mon_symbol)
         {
@@ -1699,7 +1713,7 @@ static void _find_description(bool *again, std::string *error_inout)
     else if (key_list.size() == 1)
     {
         if (_do_description(key_list[0], type))
-            wait_for_keypress();
+            getchm();
         return;
     }
 
@@ -1722,7 +1736,7 @@ static void _find_description(bool *again, std::string *error_inout)
 
     // For tiles builds use a tiles menu to display monsters.
     const bool text_only =
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
         !(doing_mons || doing_features || doing_spells);
 #else
         true;
@@ -1804,7 +1818,7 @@ static void _find_description(bool *again, std::string *error_inout)
             me = new MenuEntry(uppercase_first(key_list[i]), MEL_ITEM, 1,
                                letter);
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
             if (doing_spells)
             {
                 spell_type spell = spell_by_name(str);
@@ -1852,7 +1866,7 @@ static void _find_description(bool *again, std::string *error_inout)
                 key = *((std::string*) sel[0]->data);
 
             if (_do_description(key, type))
-                wait_for_keypress();
+                getchm();
         }
     }
 }
@@ -2001,7 +2015,7 @@ static int _show_keyhelp_menu(const std::vector<formatted_string> &lines,
             "<w>%</w>: Table of aptitudes\n"
             "<w>/</w>: Lookup description\n"
             "<w>Q</w>: FAQ\n"
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
             "<w>T</w>: Tiles key help\n"
 #endif
             "<w>V</w>: Version information\n"
@@ -2057,24 +2071,6 @@ static int _show_keyhelp_menu(const std::vector<formatted_string> &lines,
             std::string fname = canonicalise_file_separator(help_files[i].name);
             FILE* fp = fopen_u(datafile_path(fname, false).c_str(), "r");
 
-#if defined(TARGET_OS_DOS)
-            if (!fp)
-            {
- #ifdef DEBUG_FILES
-                mprf(MSGCH_DIAGNOSTICS, "File '%s' could not be opened.",
-                     help_files[i].name);
- #endif
-                if (get_dos_compatible_file_name(&fname))
-                {
- #ifdef DEBUG_FILES
-                    mprf(MSGCH_DIAGNOSTICS,
-                         "Attempting to open file '%s'", fname.c_str());
- #endif
-                    fp = fopen_u(datafile_path(fname, false).c_str(), "r");
-                }
-            }
-#endif
-
             if (!fp)
                 continue;
 
@@ -2153,6 +2149,11 @@ void show_butchering_help()
     show_specific_help(getHelpString("butchering"));
 }
 
+void show_skill_menu_help()
+{
+    show_specific_help(getHelpString("skill-menu"));
+}
+
 static void _add_command(column_composer &cols, const int column,
                          const command_type cmd,
                          const std::string desc,
@@ -2366,7 +2367,7 @@ static void _add_formatted_keyhelp(column_composer &cols)
                          CMD_MAKE_NOTE, CMD_DISPLAY_COMMANDS, 0);
     _add_command(cols, 0, CMD_MACRO_ADD, "add macro (also <w>Ctrl-D</w>)", 2);
     _add_command(cols, 0, CMD_ADJUST_INVENTORY, "reassign inventory/spell letters", 2);
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     _add_command(cols, 0, CMD_EDIT_PLAYER_TILE, "edit player doll", 2);
 #else
     _add_command(cols, 0, CMD_READ_MESSAGES, "read messages (online play only)", 2);
@@ -2472,6 +2473,7 @@ static void _add_formatted_keyhelp(column_composer &cols)
     _add_command(cols, 1, CMD_DROP, "Drop an item", 2);
     _add_insert_commands(cols, 1, "<w>%#</w>: Drop exact number of items",
                          CMD_DROP, 0);
+    _add_command(cols, 1, CMD_DROP_LAST, "Drop the last item(s) you picked up", 2);
     _add_command(cols, 1, CMD_BUTCHER, "Chop up a corpse", 2);
 
     {
@@ -2497,7 +2499,7 @@ static void _add_formatted_keyhelp(column_composer &cols)
                     CMD_SEARCH_STASHES, CMD_INTERLEVEL_TRAVEL,
                     CMD_DISPLAY_SPELLS, CMD_DISPLAY_SKILLS, CMD_USE_ABILITY,
                     0);
-    linebreak_string2(text, 40);
+    linebreak_string(text, 40);
 
     cols.add_formatted(
             1, text,
@@ -2659,6 +2661,7 @@ static void _add_formatted_hints_help(column_composer &cols)
     _add_command(cols, 1, CMD_DISPLAY_INVENTORY, "list inventory (select item to view it)", 2);
     _add_command(cols, 1, CMD_PICKUP, "pick up item from ground (also <w>g</w>)", 2);
     _add_command(cols, 1, CMD_DROP, "drop item", 2);
+    _add_command(cols, 1, CMD_DROP_LAST, "drop the last item(s) you picked up", 2);
 
     cols.add_formatted(
             1,
@@ -2730,6 +2733,7 @@ int list_wizard_commands(bool do_redraw_screen)
                        "<w>_</w>      : gain religion\n"
                        "<w>^</w>      : set piety to a value\n"
                        "<w>@</w>      : set Str Int Dex\n"
+                       "<w>Ctrl-Z</w> : gain lots of Zot Points\n"
                        "\n"
                        "<yellow>Create level features</yellow>\n"
                        "<w>l</w>      : make entrance to labyrinth\n"
@@ -2771,6 +2775,7 @@ int list_wizard_commands(bool do_redraw_screen)
                        "<w>X</w>      : make Xom do something now\n"
                        "<w>z</w>      : cast spell by number/name\n"
                        "<w>W</w>      : god wrath\n"
+                       "<w>w</w>      : god mollification\n"
                        "<w>Ctrl-V</w> : toggle xray vision\n"
                        "\n"
                        "<yellow>Monster related commands</yellow>\n"
