@@ -14,6 +14,10 @@
 
 char_choice_restriction job_allowed(species_type speci, job_type job)
 {
+    // Octopodes are not targetted at 0.9.
+    if (speci == SP_OCTOPODE && Version::ReleaseType() != VER_ALPHA)
+        return (CC_BANNED);
+
     switch (job)
     {
         case JOB_FIGHTER:
@@ -31,6 +35,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_DEMIGOD:
             case SP_MUMMY:
             case SP_VAMPIRE:
+            case SP_OCTOPODE:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -39,7 +44,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
         case JOB_GLADIATOR:
             switch (speci)
         {
-            case SP_CAT:
+            case SP_FELID:
                 return (CC_BANNED);
             case SP_DEEP_ELF:
             case SP_SLUDGE_ELF:
@@ -52,6 +57,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_DEMIGOD:
             case SP_MUMMY:
             case SP_VAMPIRE:
+            case SP_OCTOPODE:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -60,7 +66,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
         case JOB_MONK:
             switch (speci)
         {
-            case SP_CAT:
+            case SP_FELID:
                 return (CC_BANNED);
             case SP_HIGH_ELF:
             case SP_DEEP_ELF:
@@ -74,6 +80,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_OGRE:
             case SP_DEMIGOD:
             case SP_MUMMY:
+            case SP_OCTOPODE:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -91,6 +98,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_MUMMY:
             case SP_GHOUL:
             case SP_VAMPIRE:
+            case SP_OCTOPODE:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -121,7 +129,8 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_MUMMY:
             case SP_GHOUL:
             case SP_VAMPIRE:
-            case SP_CAT:
+            case SP_FELID:
+            case SP_OCTOPODE:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -147,7 +156,8 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_MUMMY:
             case SP_GHOUL:
             case SP_VAMPIRE:
-            case SP_CAT:
+            case SP_FELID:
+            case SP_OCTOPODE:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -175,7 +185,8 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_TROLL:
             case SP_KENKU:
             case SP_BASE_DRACONIAN:
-            case SP_CAT:
+            case SP_FELID:
+            case SP_OCTOPODE:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -197,13 +208,14 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_OGRE:
             case SP_MINOTAUR:
             case SP_KENKU:
-            case SP_CAT:
+            case SP_FELID:
+            case SP_OCTOPODE:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
         }
 
-        case JOB_CRUSADER:
+        case JOB_SKALD:
             switch (speci)
         {
             case SP_DEEP_ELF:
@@ -219,6 +231,8 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_KENKU:
             case SP_MUMMY:
             case SP_GHOUL:
+            case SP_FELID:
+            case SP_OCTOPODE:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -243,6 +257,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_MUMMY:
             case SP_GHOUL:
             case SP_VAMPIRE:
+            case SP_OCTOPODE:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -261,7 +276,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_MINOTAUR:
             case SP_GHOUL:
             case SP_VAMPIRE:
-            case SP_CAT:
+            case SP_FELID:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -273,6 +288,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_SLUDGE_ELF:
             case SP_MOUNTAIN_DWARF:
             case SP_DEEP_DWARF:
+            case SP_HILL_ORC:
             case SP_MERFOLK:
             case SP_HALFLING:
             case SP_KOBOLD:
@@ -283,7 +299,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_MINOTAUR:
             case SP_GHOUL:
             case SP_VAMPIRE:
-            case SP_CAT:
+            case SP_FELID:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -307,7 +323,8 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_DEMONSPAWN:
             case SP_MUMMY:
             case SP_GHOUL:
-            case SP_CAT:
+            case SP_FELID:
+            case SP_OCTOPODE:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -385,7 +402,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_MUMMY:
             case SP_GHOUL:
             case SP_VAMPIRE:
-            case SP_CAT:
+            case SP_FELID:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -403,6 +420,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_TROLL:
             case SP_MINOTAUR:
             case SP_KENKU:
+            case SP_FELID:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -422,7 +440,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_MUMMY:
             case SP_GHOUL:
             case SP_VAMPIRE:
-            case SP_CAT:
+            case SP_FELID:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -441,7 +459,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_KENKU:
             case SP_MUMMY:
             case SP_VAMPIRE:
-            case SP_CAT:
+            case SP_FELID:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -487,7 +505,8 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_DEMONSPAWN:
             case SP_MUMMY:
             case SP_GHOUL:
-            case SP_CAT:
+            case SP_FELID:
+            case SP_OCTOPODE:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -496,7 +515,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
         case JOB_ASSASSIN:
             switch (speci)
         {
-            case SP_CAT:
+            case SP_FELID:
                 return (CC_BANNED);
             case SP_HIGH_ELF:
             case SP_DEEP_ELF:
@@ -513,6 +532,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_DEMONSPAWN:
             case SP_MUMMY:
             case SP_GHOUL:
+            case SP_OCTOPODE:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -521,7 +541,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
         case JOB_HUNTER:
             switch (speci)
         {
-            case SP_CAT:
+            case SP_FELID:
                 return (CC_BANNED);
             case SP_DEEP_ELF:
             case SP_HILL_ORC:
@@ -534,6 +554,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_MUMMY:
             case SP_GHOUL:
             case SP_VAMPIRE:
+            case SP_OCTOPODE:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -542,7 +563,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
         case JOB_ARTIFICER:
             switch (speci)
         {
-            case SP_CAT:
+            case SP_FELID:
                 return (CC_BANNED);
             case SP_HIGH_ELF:
             case SP_DEEP_ELF:
@@ -557,6 +578,7 @@ char_choice_restriction job_allowed(species_type speci, job_type job)
             case SP_MUMMY:
             case SP_GHOUL:
             case SP_VAMPIRE:
+            case SP_OCTOPODE:
                 return (CC_RESTRICTED);
             default:
                 return (CC_UNRESTRICTED);
@@ -584,45 +606,6 @@ bool is_good_combination(species_type spc, job_type job, bool good)
     return (restrict != CC_BANNED);
 }
 
-// Is the given book restricted for the character defined by ng?
-// Only uses ng.species.
-char_choice_restriction book_restriction(startup_book_type booktype,
-                                         const newgame_def &ng)
-{
-    ASSERT(is_valid_species(ng.species));
-    switch (booktype)
-    {
-        case SBT_FIRE: // Fire/Earth book
-            switch (ng.species)
-        {
-            case SP_HIGH_ELF:
-            case SP_MERFOLK:
-            case SP_HALFLING:
-            case SP_VAMPIRE:
-            case SP_KENKU:
-                return (CC_RESTRICTED);
-            default:
-                return (CC_UNRESTRICTED);
-        }
-            break;
-
-        case SBT_COLD: // Ice/Air book
-            switch (ng.species)
-        {
-            case SP_MOUNTAIN_DWARF:
-            case SP_DEEP_DWARF:
-            case SP_HILL_ORC:
-                return (CC_RESTRICTED);
-            default:
-                return (CC_UNRESTRICTED);
-        }
-            break;
-
-        default:
-            return (CC_UNRESTRICTED);
-    }
-}
-
 // Is the given god restricted for the character defined by ng?
 // Only uses ng.species and ng.job.
 char_choice_restriction weapon_restriction(weapon_type wpn,
@@ -633,20 +616,11 @@ char_choice_restriction weapon_restriction(weapon_type wpn,
     switch (wpn)
     {
         case WPN_UNARMED:
-            if (!species_has_claws(ng.species) && ng.job != JOB_MONK)
-                return (CC_BANNED);
-            switch (ng.species)
-            {
-            case SP_DEEP_ELF:
-            case SP_HIGH_ELF:
-                return (CC_RESTRICTED);
-            default:
+            if (species_has_claws(ng.species))
                 return (CC_UNRESTRICTED);
-            }
+            return (CC_BANNED);
 
         case WPN_SHORT_SWORD:
-            if (ng.job == JOB_MONK)
-                return (CC_BANNED);
             switch (ng.species)
             {
             case SP_NAGA:
@@ -671,16 +645,12 @@ char_choice_restriction weapon_restriction(weapon_type wpn,
 
             // Maces and hand axes usually share the same restrictions.
         case WPN_MACE:
-            if (ng.job == JOB_MONK)
-                return (CC_BANNED);
             if (ng.species == SP_TROLL)
                 return (CC_UNRESTRICTED);
             if (ng.species == SP_VAMPIRE)
                 return (CC_RESTRICTED);
             // else fall-through
         case WPN_HAND_AXE:
-            if (ng.job == JOB_MONK)
-                return (CC_BANNED);
             switch (ng.species)
             {
             case SP_HUMAN:
@@ -695,6 +665,7 @@ char_choice_restriction weapon_restriction(weapon_type wpn,
             case SP_DEMIGOD:
             case SP_DEMONSPAWN:
             case SP_VAMPIRE:
+            case SP_OCTOPODE:
                 return (CC_UNRESTRICTED);
 
             default:
@@ -703,8 +674,6 @@ char_choice_restriction weapon_restriction(weapon_type wpn,
             }
 
         case WPN_SPEAR:
-            if (ng.job == JOB_MONK)
-                return (CC_BANNED);
             switch (ng.species)
             {
             case SP_HUMAN:
@@ -718,6 +687,7 @@ char_choice_restriction weapon_restriction(weapon_type wpn,
             case SP_DEMIGOD:
             case SP_DEMONSPAWN:
             case SP_MUMMY:
+            case SP_OCTOPODE:
                 return (CC_UNRESTRICTED);
 
             default:
@@ -744,6 +714,7 @@ char_choice_restriction weapon_restriction(weapon_type wpn,
             case SP_DEMONSPAWN:
             case SP_MUMMY:
             case SP_VAMPIRE:
+            case SP_OCTOPODE:
                 return (CC_UNRESTRICTED);
 
             default:
@@ -774,57 +745,11 @@ char_choice_restriction weapon_restriction(weapon_type wpn,
             // Both are polearms, right?
             return (weapon_restriction(WPN_SPEAR, ng));
 
-        case WPN_QUARTERSTAFF:
-            if (ng.job != JOB_MONK)
-                return (CC_BANNED);
-            switch (ng.species)
-            {
-            case SP_HALFLING:
-            case SP_MERFOLK:
-            case SP_SPRIGGAN:
-            case SP_TROLL:
-            case SP_VAMPIRE:
-                return (CC_RESTRICTED);
-            default:
-                return (CC_UNRESTRICTED);
-            }
-
         case WPN_ANKUS:
-            if (species_genus(ng.species) == GENPC_OGREISH
-                && ng.job != JOB_MONK)
+            if (species_genus(ng.species) == GENPC_OGREISH)
                 return (CC_UNRESTRICTED);
             // intentional fall-through
         default:
             return (CC_BANNED);
     }
 }
-
-// Is the given god restricted for the character defined by ng?
-// Only uses ng.species and ng.job.
-char_choice_restriction religion_restriction(god_type god,
-                                             const newgame_def &ng)
-{
-    ASSERT(is_valid_species(ng.species));
-    ASSERT(is_valid_job(ng.job));
-
-    if (ng.species == SP_DEMIGOD)
-        return (CC_BANNED);
-    if (ng.job != JOB_PRIEST)
-        return (CC_BANNED);
-
-    switch (god)
-    {
-        case GOD_BEOGH:
-            if (ng.job == JOB_PRIEST && ng.species == SP_HILL_ORC)
-                return (CC_UNRESTRICTED);
-            return (CC_BANNED);
-
-        case GOD_ZIN:
-            if (ng.job == JOB_PRIEST)
-                return (CC_RESTRICTED);
-            return (CC_BANNED);
-
-        default:
-            return (CC_BANNED);
-    }
-}
